# Generated by Django 4.0.6 on 2022-09-19 04:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aadiscordbot', '0007_quotemessage'),
    ]

    operations = [
        migrations.AddField(
            model_name='channels',
            name='deleted',
            field=models.BooleanField(default=False, verbose_name='Deleted'),
        ),
    ]
