# Generated by Django 3.2.8 on 2022-01-26 05:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('discord', '0003_big_overhaul'),
        ('aadiscordbot', '0004_settings'),
    ]

    operations = [
        migrations.AddField(
            model_name='reactionrolemessage',
            name='non_auth_users',
            field=models.BooleanField(
                default=False, help_text='Can Non Authed/public discord members gain groups from this Reaction Roles Message'),
        ),
        migrations.AlterField(
            model_name='authbotconfiguration',
            name='admin_users',
            field=models.ManyToManyField(blank=True, to='discord.DiscordUser'),
        ),
    ]
