# Generated by Django 4.0.6 on 2022-09-17 05:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aadiscordbot', '0005_rr_fixes_blank_admins'),
    ]

    operations = [
        migrations.CreateModel(
            name='GoodbyeMessage',
            fields=[
                ('id', models.AutoField(auto_created=True,
                 primary_key=True, serialize=False, verbose_name='ID')),
                ('message', models.TextField(verbose_name='Goodbye Message')),
                ('authenticated', models.BooleanField(
                    verbose_name='Valid for Authenticated Users')),
                ('unauthenticated', models.BooleanField(
                    verbose_name='Valid for Un-Authenticated Users')),
            ],
            options={
                'verbose_name': 'Goodbye Message',
                'verbose_name_plural': 'Goodbye Messages',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='WelcomeMessage',
            fields=[
                ('id', models.AutoField(auto_created=True,
                 primary_key=True, serialize=False, verbose_name='ID')),
                ('message', models.TextField(verbose_name='Welcome Message')),
                ('authenticated', models.BooleanField(
                    verbose_name='Valid for Authenticated Users')),
                ('unauthenticated', models.BooleanField(
                    verbose_name='Valid for Un-Authenticated Users')),
            ],
            options={
                'verbose_name': 'Welcome Message',
                'verbose_name_plural': 'Welcome Messages',
                'default_permissions': (),
            },
        ),
    ]
